@@ -3,7 +3,15 @@ main <- function ()
     devel <- FALSE
 
 
-    # Sys.setenv(R_THIS_PATH_DEFINES = "TRUE"); warning("in './tools/configure.R':\n comment out this line later", call. = FALSE, immediate. = TRUE)
+    FILE <- "./tools/building-initial-tarball"
+    if (first <- file.exists(FILE))
+        if (!file.remove(FILE))
+            stop(sprintf("unable to remove file '%s'", FILE))
+
+
+    FILE <- "./tools/for-r-mac-builder"
+    if (file.exists(FILE))
+        Sys.setenv(R_THIS_PATH_DEFINES = "TRUE")
 
 
     if (devel)
@@ -17,6 +25,7 @@ main <- function ()
         )
 
 
+    # we need the contents of the DESCRIPTION file
     desc <- read.dcf("./DESCRIPTION", keep.white = c("Description", "Authors@R", "Author", "Built", "Packaged"))
     if (nrow(desc) != 1L)
         stop("contains a blank line", call. = FALSE)
@@ -30,16 +39,15 @@ main <- function ()
                     pos <- which(!ind)
                     desc[pos] <- iconv(desc[pos], "UTF-8", "UTF-8", sub = "byte")
                 }
-            }
-            else if (encoding == "latin1")
+            } else if (encoding == "latin1") {
                 Encoding(desc) <- "latin1"
-            else desc <- iconv(desc, encoding, "", sub = "byte")
+            } else desc <- iconv(desc, encoding, "", sub = "byte")
         }
     } else {
         if (!is.na(encoding <- desc["Encoding"])) {
-            if (encoding %in% c("latin1", "UTF-8"))
+            if (encoding %in% c("latin1", "UTF-8")) {
                 Encoding(desc) <- encoding
-            else desc <- iconv(desc, encoding, "", sub = "byte")
+            } else desc <- iconv(desc, encoding, "", sub = "byte")
         }
     }
     pkgname <- Sys.getenv("R_PACKAGE_NAME")
@@ -63,7 +71,7 @@ main <- function ()
     }
 
 
-    if (devel) {
+    if (first && devel) {
         # replace 'devel' in files with the current package version
         replace.devel.with.current.version <- function(file, old, new) {
             x <- readLines2(file)
@@ -92,69 +100,72 @@ main <- function ()
     }
 
 
-    # we need to add the common macros to the files which do not have access.
-    # for R < 3.2.0, this is ALL of the Rd files. otherwise, only
-    # './inst/NEWS.Rd' will need them
-    commonmacros <- c(
-        unlist(lapply(list.files("./man/macros", "\\.Rd$", all.files = TRUE, full.names = TRUE, ignore.case = TRUE), readLines2)),
-        if (getRversion() < "3.2.0") {
-            # \packageAuthor{} and \packageMaintainer{} are not defined for
-            # R < 3.2.0, we will define them here ourselves
-            fun <- function(x) {
-                .fun <- function(x, include.hash = TRUE) {
-                    paste0("rawToChar(as.raw(c(", paste0(as.integer(charToRaw(x)), "L", collapse = ", "), if (include.hash) ", as.null(\"#1\")", ")))")
+    # we need to add the common macros to the files which do not
+    # have access. for R < 3.2.0, this is ALL of the Rd files.
+    # otherwise, only './inst/NEWS.Rd' will need them
+    Rdfiles <- if (first) "./inst/NEWS.Rd" else character(0)
+    if (!first && getRversion() < "3.2.0")
+        Rdfiles <- c(Rdfiles, list.files("./man", "\\.Rd$", all.files = TRUE, full.names = TRUE, ignore.case = TRUE))
+    if (length(Rdfiles)) {
+        commonmacros <- c(
+            unlist(lapply(list.files("./man/macros", "\\.Rd$", all.files = TRUE, full.names = TRUE, ignore.case = TRUE), readLines2)),
+            if (getRversion() < "3.2.0") {
+                # \packageAuthor{} and \packageMaintainer{} are not defined for
+                # R < 3.2.0, we will define them here ourselves
+                fun <- function(x) {
+                    .fun <- function(x, include.hash = TRUE) {
+                        paste0("rawToChar(as.raw(c(", paste0(as.integer(charToRaw(x)), "L", collapse = ", "), if (include.hash) ", as.null(\"#1\")", ")))")
+                    }
+                    value <- .fun(gsub("([%{}\\])", "\\\\\\1", x, useBytes = TRUE))
+                    if (Encoding(x) != "unknown")
+                        value <- paste0("`Encoding<-`(", value, ", ", .fun(Encoding(x), include.hash = FALSE), ")")
+                    value
                 }
-                value <- .fun(gsub("([%{}\\])", "\\\\\\1", x, useBytes = TRUE))
-                if (Encoding(x) != "unknown")
-                    value <- paste0("`Encoding<-`(", value, ", ", .fun(Encoding(x), include.hash = FALSE), ")")
-                value
+                c(
+                    paste0("\\newcommand{\\packageAuthor",     "}{\\Sexpr[results=rd,stage=build]{", fun(desc["Author"])    , "}}"),
+                    paste0("\\newcommand{\\packageMaintainer", "}{\\Sexpr[results=rd,stage=build]{", fun(desc["Maintainer"]), "}}")
+                )
             }
-            c(
-                paste0("\\newcommand{\\packageAuthor",     "}{\\Sexpr[results=rd,stage=build]{", fun(desc["Author"])    , "}}"),
-                paste0("\\newcommand{\\packageMaintainer", "}{\\Sexpr[results=rd,stage=build]{", fun(desc["Maintainer"]), "}}")
-            )
+        )
+        for (Rdfile in Rdfiles) {
+            x <- readLines2(Rdfile)
+            # add the common macros directly before the title
+            n <- grep("^\\\\title\\{", x) - 1L
+            if (length(n) > 1L)
+                stop(gettextf("in '%s':\n multiple lines that start with \\title{", Rdfile))
+            if (length(n) < 1L)
+                stop(gettextf("in '%s':\n no lines that start with \\title{", Rdfile))
+            x <- if (n) {
+                c(x[seq_len(n)], commonmacros, x[-seq_len(n)])
+            } else c(commonmacros, x)
+            writeLines2(x, Rdfile)
         }
-    )
-    Rdfiles <- "./inst/NEWS.Rd"
-    if (getRversion() < "3.2.0")
-        Rdfiles <- c(Rdfiles, list.files("./man", "\\.Rd$", all.files = TRUE, recursive = FALSE, full.names = TRUE, ignore.case = TRUE))
-    for (Rdfile in Rdfiles) {
-        x <- readLines2(Rdfile)
-        # add the common macros directly before the title
-        n <- grep("^\\\\title\\{", x) - 1L
-        if (length(n) > 1L)
-            stop(gettextf("in '%s':\n multiple lines that start with \\title{", Rdfile))
-        if (length(n) < 1L)
-            stop(gettextf("in '%s':\n no lines that start with \\title{", Rdfile))
-        x <- if (n) {
-            c(x[seq_len(n)], commonmacros, x[-seq_len(n)])
-        } else c(commonmacros, x)
-        writeLines2(x, Rdfile)
     }
-    if (getRversion() < "3.2.0")
+    if (!first && getRversion() < "3.2.0")
         unlink("./man/macros", recursive = TRUE, force = TRUE)
 
 
-    # *.c and *.h must use Unix (LF) under Unix-alikes
-    writeLines2(description = "./src/defines.h", mode = "wb", {
-        R_THIS_PATH_DEFINES <- devel && as.logical(Sys.getenv("R_THIS_PATH_DEFINES"))
+    if (!first) {
+        R_THIS_PATH_DEFINES <- as.logical(Sys.getenv("R_THIS_PATH_DEFINES"))
         if (is.na(R_THIS_PATH_DEFINES)) {
-            libname <- Sys.getenv("R_LIBRARY_DIR")
-            R_THIS_PATH_DEFINES <- !(
-                is.na(libname)                                            ||
+            if (devel) {
+                libname <- Sys.getenv("R_LIBRARY_DIR")
+                R_THIS_PATH_DEFINES <- !(
+                    is.na(libname)                                            ||
                     !nzchar(libname)                                          ||
-                    grepl("/this\\.path\\.Rcheck$", libname, useBytes = TRUE) ||
-                    grepl("/CRAN", libname, fixed = TRUE, useBytes = TRUE)
-            )
+                    grepl("/this\\.path\\.Rcheck$", libname, useBytes = TRUE)
+                )
+            } else R_THIS_PATH_DEFINES <- FALSE
         }
-        if (R_THIS_PATH_DEFINES) {
-            c(
+        if (R_THIS_PATH_DEFINES)
+            writeLines2(c(
                 "#ifndef R_THIS_PATH_DEFINES",
                 "#define R_THIS_PATH_DEFINES",
                 "#endif"
-            )
-        } else character(0)
-    })
+            ),
+            # *.c and *.h must use Unix (LF) under Unix-alikes
+            "./src/defines.h", "wb")
+    }
 }
 
 
